@@ -8,10 +8,14 @@ class ALGORITHMS(object):
     RS256 = 'RS256'
     RS384 = 'RS384'
     RS512 = 'RS512'
+    ES256 = 'ES256'
+    ES384 = 'ES384'
+    ES512 = 'ES512'
 
     HMAC = (HS256, HS384, HS512)
     RSA = (RS256, RS384, RS512)
+    EC = (ES256, ES384, ES512)
 
-    SUPPORTED = (HS256, HS384, HS512, RS256, RS384, RS512)
+    SUPPORTED = HMAC + RSA + EC
 
-    ALL = (NONE, HS256, HS384, HS512, RS256, RS384, RS512)
+    ALL = SUPPORTED + (NONE, )
