@@ -2,7 +2,6 @@
 import hashlib
 import hmac
 import six
-import struct
 
 import Crypto.Hash.SHA256
 import Crypto.Hash.SHA384
@@ -18,6 +17,13 @@ from jose.exceptions import JWKError
 from jose.exceptions import JWSError
 from jose.exceptions import JOSEError
 
+# PyCryptodome's RSA module doesn't have PyCrypto's _RSAobj class
+# Instead it has a class named RsaKey, which serves the same purpose.
+if hasattr(RSA, '_RSAobj'):
+    _RSAKey = RSA._RSAobj
+else:
+    _RSAKey = RSA.RsaKey
+
 
 def get_algorithm_object(algorithm):
     """
@@ -204,7 +210,7 @@ class RSAKey(Key):
 
     def process_prepare_key(self, key):
 
-        if isinstance(key, (RSA._RSAobj, RSAKey)):
+        if isinstance(key, (_RSAKey, RSAKey)):
             return key
 
         if isinstance(key, dict):
